@@ -12,9 +12,11 @@ class Compressor : public PluginBase {
 
   GstElement* compressor = nullptr;
 
-  sigc::connection compression_connection;
+  sigc::connection input_level_connection, output_level_connection,
+      reduction_connection, sidechain_connection, curve_connection;
 
-  sigc::signal<void, double> compression;
+  sigc::signal<void, std::array<double, 2>> input_level, output_level;
+  sigc::signal<void, double> reduction, sidechain, curve;
 
  private:
   void bind_to_gsettings();
