@@ -4,10 +4,17 @@
 #include <gio/gio.h>
 #include <gst/gst.h>
 #include <memory>
-#include <mutex>
 #include <vector>
+#include "compressor.hpp"
+#include "deesser.hpp"
+#include "equalizer.hpp"
+#include "filter.hpp"
+#include "gate.hpp"
+#include "limiter.hpp"
+#include "pitch.hpp"
 #include "pulse_manager.hpp"
 #include "realtime_kit.hpp"
+#include "reverb.hpp"
 
 class PipelineBase {
  public:
@@ -19,21 +26,28 @@ class PipelineBase {
 
   PulseManager* pm = nullptr;
 
-  GstElement *pipeline = nullptr, *source = nullptr, *queue_src = nullptr,
-             *sink = nullptr, *spectrum = nullptr, *spectrum_bin = nullptr,
-             *spectrum_identity_in = nullptr, *spectrum_identity_out = nullptr,
-             *adapter = nullptr, *effects_bin = nullptr, *identity_in = nullptr,
-             *identity_out = nullptr;
+  GstElement *pipeline = nullptr, *source = nullptr, *queue_src = nullptr, *sink = nullptr, *spectrum = nullptr,
+             *spectrum_bin = nullptr, *spectrum_identity_in = nullptr, *spectrum_identity_out = nullptr,
+             *adapter = nullptr, *effects_bin = nullptr, *identity_in = nullptr, *identity_out = nullptr;
 
   GstBus* bus = nullptr;
 
-  GSettings *settings = nullptr, *child_settings = nullptr,
-            *spectrum_settings = nullptr;
+  GSettings *settings = nullptr, *child_settings = nullptr, *spectrum_settings = nullptr;
+
+  std::vector<std::string> plugins_order, plugins_order_old;
+  std::map<std::string, GstElement*> plugins;
+
+  std::unique_ptr<Limiter> limiter;
+  std::unique_ptr<Compressor> compressor;
+  std::unique_ptr<Filter> filter;
+  std::unique_ptr<Equalizer> equalizer;
+  std::unique_ptr<Reverb> reverb;
+  std::unique_ptr<Gate> gate;
+  std::unique_ptr<Deesser> deesser;
+  std::unique_ptr<Pitch> pitch;
 
   std::unique_ptr<RealtimeKit> rtkit;
 
-  std::mutex pipeline_mutex;
-
   GstClockTime state_check_timeout = 5 * GST_SECOND;
 
   bool resizing_spectrum = false;
@@ -59,6 +73,14 @@ class PipelineBase {
 
   sigc::signal<void, std::vector<float>> new_spectrum;
   sigc::signal<void, int> new_latency;
+  sigc::signal<void, std::array<double, 2>> equalizer_input_level;
+  sigc::signal<void, std::array<double, 2>> equalizer_output_level;
+  sigc::signal<void, std::array<double, 2>> pitch_input_level;
+  sigc::signal<void, std::array<double, 2>> pitch_output_level;
+  sigc::signal<void, std::array<double, 2>> gate_input_level;
+  sigc::signal<void, std::array<double, 2>> gate_output_level;
+  sigc::signal<void, std::array<double, 2>> deesser_input_level;
+  sigc::signal<void, std::array<double, 2>> deesser_output_level;
 
  protected:
   void set_pulseaudio_props(std::string props);
@@ -78,8 +100,11 @@ class PipelineBase {
 
   std::vector<std::shared_ptr<AppInfo>> apps_list;
 
+  sigc::connection timeout_connection;
+
   void init_spectrum_bin();
   void init_effects_bin();
+  bool apps_want_to_play();
 
   GstElement* get_required_plugin(const gchar* factoryname, const gchar* name);
 };
