@@ -62,8 +62,7 @@ void on_g_changed(GObject* gobject, GParamSpec* pspec, AutoGain* a) {
 
 }  // namespace
 
-AutoGain::AutoGain(const std::string& tag, const std::string& schema)
-    : PluginBase(tag, "autogain", schema) {
+AutoGain::AutoGain(const std::string& tag, const std::string& schema) : PluginBase(tag, "autogain", schema) {
   autogain = gst_element_factory_make("peautogain", nullptr);
 
   if (is_installed(autogain)) {
@@ -71,17 +70,14 @@ AutoGain::AutoGain(const std::string& tag, const std::string& schema)
     auto in_level = gst_element_factory_make("level", "autogain_input_level");
     auto output_gain = gst_element_factory_make("volume", nullptr);
     auto out_level = gst_element_factory_make("level", "autogain_output_level");
-    auto audioconvert_in =
-        gst_element_factory_make("audioconvert", "autogain_audioconvert_in");
-    auto audioconvert_out =
-        gst_element_factory_make("audioconvert", "autogain_audioconvert_out");
+    auto audioconvert_in = gst_element_factory_make("audioconvert", "autogain_audioconvert_in");
+    auto audioconvert_out = gst_element_factory_make("audioconvert", "autogain_audioconvert_out");
 
-    gst_bin_add_many(GST_BIN(bin), input_gain, in_level, audioconvert_in,
-                     autogain, audioconvert_out, output_gain, out_level,
-                     nullptr);
+    gst_bin_add_many(GST_BIN(bin), input_gain, in_level, audioconvert_in, autogain, audioconvert_out, output_gain,
+                     out_level, nullptr);
 
-    gst_element_link_many(input_gain, in_level, audioconvert_in, autogain,
-                          audioconvert_out, output_gain, out_level, nullptr);
+    gst_element_link_many(input_gain, in_level, audioconvert_in, autogain, audioconvert_out, output_gain, out_level,
+                          nullptr);
 
     auto pad_sink = gst_element_get_static_pad(input_gain, "sink");
     auto pad_src = gst_element_get_static_pad(out_level, "src");
@@ -94,12 +90,9 @@ AutoGain::AutoGain(const std::string& tag, const std::string& schema)
 
     bind_to_gsettings();
 
-    g_settings_bind(settings, "post-messages", in_level, "post-messages",
-                    G_SETTINGS_BIND_DEFAULT);
-    g_settings_bind(settings, "post-messages", out_level, "post-messages",
-                    G_SETTINGS_BIND_DEFAULT);
-    g_settings_bind(settings, "post-messages", autogain, "notify-host",
-                    G_SETTINGS_BIND_DEFAULT);
+    g_settings_bind(settings, "post-messages", in_level, "post-messages", G_SETTINGS_BIND_DEFAULT);
+    g_settings_bind(settings, "post-messages", out_level, "post-messages", G_SETTINGS_BIND_DEFAULT);
+    g_settings_bind(settings, "post-messages", autogain, "notify-host", G_SETTINGS_BIND_DEFAULT);
 
     g_signal_connect(autogain, "notify::m", G_CALLBACK(on_m_changed), this);
     g_signal_connect(autogain, "notify::s", G_CALLBACK(on_s_changed), this);
@@ -109,15 +102,11 @@ AutoGain::AutoGain(const std::string& tag, const std::string& schema)
     g_signal_connect(autogain, "notify::lra", G_CALLBACK(on_lra_changed), this);
     g_signal_connect(autogain, "notify::g", G_CALLBACK(on_g_changed), this);
 
-    g_settings_bind_with_mapping(
-        settings, "input-gain", input_gain, "volume", G_SETTINGS_BIND_DEFAULT,
-        util::db20_gain_to_linear_double, util::linear_double_gain_to_db20,
-        nullptr, nullptr);
+    g_settings_bind_with_mapping(settings, "input-gain", input_gain, "volume", G_SETTINGS_BIND_DEFAULT,
+                                 util::db20_gain_to_linear_double, util::linear_double_gain_to_db20, nullptr, nullptr);
 
-    g_settings_bind_with_mapping(
-        settings, "output-gain", output_gain, "volume", G_SETTINGS_BIND_DEFAULT,
-        util::db20_gain_to_linear_double, util::linear_double_gain_to_db20,
-        nullptr, nullptr);
+    g_settings_bind_with_mapping(settings, "output-gain", output_gain, "volume", G_SETTINGS_BIND_DEFAULT,
+                                 util::db20_gain_to_linear_double, util::linear_double_gain_to_db20, nullptr, nullptr);
 
     // useless write just to force callback call
 
@@ -132,16 +121,12 @@ AutoGain::~AutoGain() {
 }
 
 void AutoGain::bind_to_gsettings() {
-  g_settings_bind_with_mapping(settings, "target", autogain, "target",
-                               G_SETTINGS_BIND_GET, util::double_to_float,
+  g_settings_bind_with_mapping(settings, "target", autogain, "target", G_SETTINGS_BIND_GET, util::double_to_float,
                                nullptr, nullptr, nullptr);
 
-  g_settings_bind(settings, "weight-m", autogain, "weight-m",
-                  G_SETTINGS_BIND_DEFAULT);
+  g_settings_bind(settings, "weight-m", autogain, "weight-m", G_SETTINGS_BIND_DEFAULT);
 
-  g_settings_bind(settings, "weight-s", autogain, "weight-s",
-                  G_SETTINGS_BIND_DEFAULT);
+  g_settings_bind(settings, "weight-s", autogain, "weight-s", G_SETTINGS_BIND_DEFAULT);
 
-  g_settings_bind(settings, "weight-i", autogain, "weight-i",
-                  G_SETTINGS_BIND_DEFAULT);
+  g_settings_bind(settings, "weight-i", autogain, "weight-i", G_SETTINGS_BIND_DEFAULT);
 }
