@@ -8,14 +8,10 @@
 G_BEGIN_DECLS
 
 #define GST_TYPE_PEAUTOGAIN (gst_peautogain_get_type())
-#define GST_PEAUTOGAIN(obj) \
-  (G_TYPE_CHECK_INSTANCE_CAST((obj), GST_TYPE_PEAUTOGAIN, GstPeautogain))
-#define GST_PEAUTOGAIN_CLASS(klass) \
-  (G_TYPE_CHECK_CLASS_CAST((klass), GST_TYPE_PEAUTOGAIN, GstPeautogainClass))
-#define GST_IS_PEAUTOGAIN(obj) \
-  (G_TYPE_CHECK_INSTANCE_TYPE((obj), GST_TYPE_PEAUTOGAIN))
-#define GST_IS_PEAUTOGAIN_CLASS(obj) \
-  (G_TYPE_CHECK_CLASS_TYPE((klass), GST_TYPE_PEAUTOGAIN))
+#define GST_PEAUTOGAIN(obj) (G_TYPE_CHECK_INSTANCE_CAST((obj), GST_TYPE_PEAUTOGAIN, GstPeautogain))
+#define GST_PEAUTOGAIN_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST((klass), GST_TYPE_PEAUTOGAIN, GstPeautogainClass))
+#define GST_IS_PEAUTOGAIN(obj) (G_TYPE_CHECK_INSTANCE_TYPE((obj), GST_TYPE_PEAUTOGAIN))
+#define GST_IS_PEAUTOGAIN_CLASS(obj) (G_TYPE_CHECK_CLASS_TYPE((klass), GST_TYPE_PEAUTOGAIN))
 
 typedef struct _GstPeautogain GstPeautogain;
 typedef struct _GstPeautogainClass GstPeautogainClass;
