@@ -1,8 +1,7 @@
 #include "maximizer_preset.hpp"
 
 MaximizerPreset::MaximizerPreset()
-    : output_settings(Gio::Settings::create(
-          "com.github.wwmm.pulseeffects.sinkinputs.maximizer")) {}
+    : output_settings(Gio::Settings::create("com.github.wwmm.pulseeffects.sinkinputs.maximizer")) {}
 
 void MaximizerPreset::save(boost::property_tree::ptree& root,
                            const std::string& section,
@@ -25,19 +24,16 @@ void MaximizerPreset::load(boost::property_tree::ptree& root,
 
   update_key<double>(root, settings, "ceiling", section + ".maximizer.ceiling");
 
-  update_key<double>(root, settings, "threshold",
-                     section + ".maximizer.threshold");
+  update_key<double>(root, settings, "threshold", section + ".maximizer.threshold");
 }
 
-void MaximizerPreset::write(PresetType preset_type,
-                            boost::property_tree::ptree& root) {
+void MaximizerPreset::write(PresetType preset_type, boost::property_tree::ptree& root) {
   if (preset_type == PresetType::output) {
     save(root, "output", output_settings);
   }
 }
 
-void MaximizerPreset::read(PresetType preset_type,
-                           boost::property_tree::ptree& root) {
+void MaximizerPreset::read(PresetType preset_type, boost::property_tree::ptree& root) {
   if (preset_type == PresetType::output) {
     load(root, "output", output_settings);
   }
