@@ -3,9 +3,7 @@
 
 namespace {
 
-void on_message_element(const GstBus* gst_bus,
-                        GstMessage* message,
-                        SinkInputEffects* sie) {
+void on_message_element(const GstBus* gst_bus, GstMessage* message, SinkInputEffects* sie) {
   auto src_name = GST_OBJECT_NAME(message->src);
 
   if (src_name == std::string("pitch_input_level")) {
@@ -65,10 +63,8 @@ void on_message_element(const GstBus* gst_bus,
 
 }  // namespace
 
-SinkInputEffects::SinkInputEffects(PulseManager* pulse_manager)
-    : PipelineBase("sie: ", pulse_manager) {
-  std::string pulse_props =
-      "application.id=com.github.wwmm.pulseeffects.sinkinputs";
+SinkInputEffects::SinkInputEffects(PulseManager* pulse_manager) : PipelineBase("sie: ", pulse_manager) {
+  std::string pulse_props = "application.id=com.github.wwmm.pulseeffects.sinkinputs";
 
   child_settings = g_settings_new("com.github.wwmm.pulseeffects.sinkinputs");
 
@@ -86,8 +82,7 @@ SinkInputEffects::SinkInputEffects(PulseManager* pulse_manager)
       set_output_sink_name(pm->server_info.default_sink_name);
     }
   } else {
-    bool use_default_sink =
-        g_settings_get_boolean(settings, "use-default-sink");
+    bool use_default_sink = g_settings_get_boolean(settings, "use-default-sink");
 
     if (use_default_sink) {
       set_output_sink_name(pm->server_info.default_sink_name);
@@ -104,74 +99,45 @@ SinkInputEffects::SinkInputEffects(PulseManager* pulse_manager)
     }
   }
 
-  pm->sink_input_added.connect(
-      sigc::mem_fun(*this, &SinkInputEffects::on_app_added));
-  pm->sink_input_changed.connect(
-      sigc::mem_fun(*this, &SinkInputEffects::on_app_changed));
-  pm->sink_input_removed.connect(
-      sigc::mem_fun(*this, &SinkInputEffects::on_app_removed));
-  pm->sink_changed.connect(
-      sigc::mem_fun(*this, &SinkInputEffects::on_sink_changed));
+  pm->sink_input_added.connect(sigc::mem_fun(*this, &SinkInputEffects::on_app_added));
+  pm->sink_input_changed.connect(sigc::mem_fun(*this, &SinkInputEffects::on_app_changed));
+  pm->sink_input_removed.connect(sigc::mem_fun(*this, &SinkInputEffects::on_app_removed));
+  pm->sink_changed.connect(sigc::mem_fun(*this, &SinkInputEffects::on_sink_changed));
 
-  g_settings_bind(settings, "buffer-out", source, "buffer-time",
-                  G_SETTINGS_BIND_DEFAULT);
-  g_settings_bind(settings, "latency-out", source, "latency-time",
-                  G_SETTINGS_BIND_DEFAULT);
-  g_settings_bind(settings, "buffer-out", sink, "buffer-time",
-                  G_SETTINGS_BIND_DEFAULT);
-  g_settings_bind(settings, "latency-out", sink, "latency-time",
-                  G_SETTINGS_BIND_DEFAULT);
+  g_settings_bind(settings, "buffer-out", source, "buffer-time", G_SETTINGS_BIND_DEFAULT);
+  g_settings_bind(settings, "latency-out", source, "latency-time", G_SETTINGS_BIND_DEFAULT);
+  g_settings_bind(settings, "buffer-out", sink, "buffer-time", G_SETTINGS_BIND_DEFAULT);
+  g_settings_bind(settings, "latency-out", sink, "latency-time", G_SETTINGS_BIND_DEFAULT);
 
-  g_settings_bind(settings, "blocksize-out", adapter, "blocksize",
-                  G_SETTINGS_BIND_DEFAULT);
+  g_settings_bind(settings, "blocksize-out", adapter, "blocksize", G_SETTINGS_BIND_DEFAULT);
 
   // element message callback
 
-  g_signal_connect(bus, "message::element", G_CALLBACK(on_message_element),
-                   this);
+  g_signal_connect(bus, "message::element", G_CALLBACK(on_message_element), this);
 
-  limiter = std::make_unique<Limiter>(
-      log_tag, "com.github.wwmm.pulseeffects.sinkinputs.limiter");
-  compressor = std::make_unique<Compressor>(
-      log_tag, "com.github.wwmm.pulseeffects.sinkinputs.compressor");
-  filter = std::make_unique<Filter>(
-      log_tag, "com.github.wwmm.pulseeffects.sinkinputs.filter");
-  equalizer = std::make_unique<Equalizer>(
-      log_tag, "com.github.wwmm.pulseeffects.sinkinputs.equalizer",
-      "com.github.wwmm.pulseeffects.sinkinputs.equalizer.leftchannel",
-      "com.github.wwmm.pulseeffects.sinkinputs.equalizer.rightchannel");
-  reverb = std::make_unique<Reverb>(
-      log_tag, "com.github.wwmm.pulseeffects.sinkinputs.reverb");
-  bass_enhancer = std::make_unique<BassEnhancer>(
-      log_tag, "com.github.wwmm.pulseeffects.sinkinputs.bassenhancer");
-  exciter = std::make_unique<Exciter>(
-      log_tag, "com.github.wwmm.pulseeffects.sinkinputs.exciter");
-  crossfeed = std::make_unique<Crossfeed>(
-      log_tag, "com.github.wwmm.pulseeffects.sinkinputs.crossfeed");
-  maximizer = std::make_unique<Maximizer>(
-      log_tag, "com.github.wwmm.pulseeffects.sinkinputs.maximizer");
-  multiband_compressor = std::make_unique<MultibandCompressor>(
-      log_tag, "com.github.wwmm.pulseeffects.sinkinputs.multibandcompressor");
-  loudness = std::make_unique<Loudness>(
-      log_tag, "com.github.wwmm.pulseeffects.sinkinputs.loudness");
-  gate = std::make_unique<Gate>(log_tag,
-                                "com.github.wwmm.pulseeffects.sinkinputs.gate");
-  pitch = std::make_unique<Pitch>(
-      log_tag, "com.github.wwmm.pulseeffects.sinkinputs.pitch");
-  multiband_gate = std::make_unique<MultibandGate>(
-      log_tag, "com.github.wwmm.pulseeffects.sinkinputs.multibandgate");
-  deesser = std::make_unique<Deesser>(
-      log_tag, "com.github.wwmm.pulseeffects.sinkinputs.deesser");
-  stereo_tools = std::make_unique<StereoTools>(
-      log_tag, "com.github.wwmm.pulseeffects.sinkinputs.stereotools");
-  convolver = std::make_unique<Convolver>(
-      log_tag, "com.github.wwmm.pulseeffects.sinkinputs.convolver");
-  crystalizer = std::make_unique<Crystalizer>(
-      log_tag, "com.github.wwmm.pulseeffects.sinkinputs.crystalizer");
-  autogain = std::make_unique<AutoGain>(
-      log_tag, "com.github.wwmm.pulseeffects.sinkinputs.autogain");
-  delay = std::make_unique<Delay>(
-      log_tag, "com.github.wwmm.pulseeffects.sinkinputs.delay");
+  limiter = std::make_unique<Limiter>(log_tag, "com.github.wwmm.pulseeffects.sinkinputs.limiter");
+  compressor = std::make_unique<Compressor>(log_tag, "com.github.wwmm.pulseeffects.sinkinputs.compressor");
+  filter = std::make_unique<Filter>(log_tag, "com.github.wwmm.pulseeffects.sinkinputs.filter");
+  equalizer = std::make_unique<Equalizer>(log_tag, "com.github.wwmm.pulseeffects.sinkinputs.equalizer",
+                                          "com.github.wwmm.pulseeffects.sinkinputs.equalizer.leftchannel",
+                                          "com.github.wwmm.pulseeffects.sinkinputs.equalizer.rightchannel");
+  reverb = std::make_unique<Reverb>(log_tag, "com.github.wwmm.pulseeffects.sinkinputs.reverb");
+  bass_enhancer = std::make_unique<BassEnhancer>(log_tag, "com.github.wwmm.pulseeffects.sinkinputs.bassenhancer");
+  exciter = std::make_unique<Exciter>(log_tag, "com.github.wwmm.pulseeffects.sinkinputs.exciter");
+  crossfeed = std::make_unique<Crossfeed>(log_tag, "com.github.wwmm.pulseeffects.sinkinputs.crossfeed");
+  maximizer = std::make_unique<Maximizer>(log_tag, "com.github.wwmm.pulseeffects.sinkinputs.maximizer");
+  multiband_compressor =
+      std::make_unique<MultibandCompressor>(log_tag, "com.github.wwmm.pulseeffects.sinkinputs.multibandcompressor");
+  loudness = std::make_unique<Loudness>(log_tag, "com.github.wwmm.pulseeffects.sinkinputs.loudness");
+  gate = std::make_unique<Gate>(log_tag, "com.github.wwmm.pulseeffects.sinkinputs.gate");
+  pitch = std::make_unique<Pitch>(log_tag, "com.github.wwmm.pulseeffects.sinkinputs.pitch");
+  multiband_gate = std::make_unique<MultibandGate>(log_tag, "com.github.wwmm.pulseeffects.sinkinputs.multibandgate");
+  deesser = std::make_unique<Deesser>(log_tag, "com.github.wwmm.pulseeffects.sinkinputs.deesser");
+  stereo_tools = std::make_unique<StereoTools>(log_tag, "com.github.wwmm.pulseeffects.sinkinputs.stereotools");
+  convolver = std::make_unique<Convolver>(log_tag, "com.github.wwmm.pulseeffects.sinkinputs.convolver");
+  crystalizer = std::make_unique<Crystalizer>(log_tag, "com.github.wwmm.pulseeffects.sinkinputs.crystalizer");
+  autogain = std::make_unique<AutoGain>(log_tag, "com.github.wwmm.pulseeffects.sinkinputs.autogain");
+  delay = std::make_unique<Delay>(log_tag, "com.github.wwmm.pulseeffects.sinkinputs.delay");
 
   plugins.insert(std::make_pair(limiter->name, limiter->plugin));
   plugins.insert(std::make_pair(compressor->name, compressor->plugin));
@@ -182,8 +148,7 @@ SinkInputEffects::SinkInputEffects(PulseManager* pulse_manager)
   plugins.insert(std::make_pair(exciter->name, exciter->plugin));
   plugins.insert(std::make_pair(crossfeed->name, crossfeed->plugin));
   plugins.insert(std::make_pair(maximizer->name, maximizer->plugin));
-  plugins.insert(
-      std::make_pair(multiband_compressor->name, multiband_compressor->plugin));
+  plugins.insert(std::make_pair(multiband_compressor->name, multiband_compressor->plugin));
   plugins.insert(std::make_pair(loudness->name, loudness->plugin));
   plugins.insert(std::make_pair(gate->name, gate->plugin));
   plugins.insert(std::make_pair(pitch->name, pitch->plugin));
@@ -197,9 +162,7 @@ SinkInputEffects::SinkInputEffects(PulseManager* pulse_manager)
 
   add_plugins_to_pipeline();
 
-  g_signal_connect(child_settings, "changed::plugins",
-                   G_CALLBACK(on_plugins_order_changed<SinkInputEffects>),
-                   this);
+  g_signal_connect(child_settings, "changed::plugins", G_CALLBACK(on_plugins_order_changed<SinkInputEffects>), this);
 }
 
 SinkInputEffects::~SinkInputEffects() {
@@ -252,8 +215,7 @@ void SinkInputEffects::add_plugins_to_pipeline() {
   for (auto v : plugins_order) {
     // checking if the plugin exists. If not we reset the list to default
 
-    if (std::find(default_order.begin(), default_order.end(), v) ==
-        default_order.end()) {
+    if (std::find(default_order.begin(), default_order.end(), v) == default_order.end()) {
       plugins_order = default_order;
 
       g_settings_reset(child_settings, "plugins");
@@ -278,6 +240,5 @@ void SinkInputEffects::add_plugins_to_pipeline() {
     gst_element_link(plugins[plugins_order[n - 1]], plugins[plugins_order[n]]);
   }
 
-  gst_element_link(plugins[plugins_order[plugins_order.size() - 1]],
-                   identity_out);
+  gst_element_link(plugins[plugins_order[plugins_order.size() - 1]], identity_out);
 }
