@@ -3,9 +3,7 @@
 
 namespace {
 
-void on_message_element(const GstBus* gst_bus,
-                        GstMessage* message,
-                        SourceOutputEffects* soe) {
+void on_message_element(const GstBus* gst_bus, GstMessage* message, SourceOutputEffects* soe) {
   auto src_name = GST_OBJECT_NAME(message->src);
 
   if (src_name == std::string("equalizer_input_level")) {
@@ -33,10 +31,8 @@ void on_message_element(const GstBus* gst_bus,
 
 }  // namespace
 
-SourceOutputEffects::SourceOutputEffects(PulseManager* pulse_manager)
-    : PipelineBase("soe: ", pulse_manager) {
-  std::string pulse_props =
-      "application.id=com.github.wwmm.pulseeffects.sourceoutputs";
+SourceOutputEffects::SourceOutputEffects(PulseManager* pulse_manager) : PipelineBase("soe: ", pulse_manager) {
+  std::string pulse_props = "application.id=com.github.wwmm.pulseeffects.sourceoutputs";
 
   child_settings = g_settings_new("com.github.wwmm.pulseeffects.sourceoutputs");
 
@@ -53,8 +49,7 @@ SourceOutputEffects::SourceOutputEffects(PulseManager* pulse_manager)
       set_source_monitor_name(pm->server_info.default_source_name);
     }
   } else {
-    bool use_default_source =
-        g_settings_get_boolean(settings, "use-default-source");
+    bool use_default_source = g_settings_get_boolean(settings, "use-default-source");
 
     if (use_default_source) {
       set_source_monitor_name(pm->server_info.default_source_name);
@@ -71,58 +66,37 @@ SourceOutputEffects::SourceOutputEffects(PulseManager* pulse_manager)
     }
   }
 
-  pm->source_output_added.connect(
-      sigc::mem_fun(*this, &SourceOutputEffects::on_app_added));
-  pm->source_output_changed.connect(
-      sigc::mem_fun(*this, &SourceOutputEffects::on_app_changed));
-  pm->source_output_removed.connect(
-      sigc::mem_fun(*this, &SourceOutputEffects::on_app_removed));
-  pm->source_changed.connect(
-      sigc::mem_fun(*this, &SourceOutputEffects::on_source_changed));
+  pm->source_output_added.connect(sigc::mem_fun(*this, &SourceOutputEffects::on_app_added));
+  pm->source_output_changed.connect(sigc::mem_fun(*this, &SourceOutputEffects::on_app_changed));
+  pm->source_output_removed.connect(sigc::mem_fun(*this, &SourceOutputEffects::on_app_removed));
+  pm->source_changed.connect(sigc::mem_fun(*this, &SourceOutputEffects::on_source_changed));
 
-  g_settings_bind(settings, "buffer-in", source, "buffer-time",
-                  G_SETTINGS_BIND_DEFAULT);
-  g_settings_bind(settings, "latency-in", source, "latency-time",
-                  G_SETTINGS_BIND_DEFAULT);
-  g_settings_bind(settings, "buffer-in", sink, "buffer-time",
-                  G_SETTINGS_BIND_DEFAULT);
-  g_settings_bind(settings, "latency-in", sink, "latency-time",
-                  G_SETTINGS_BIND_DEFAULT);
+  g_settings_bind(settings, "buffer-in", source, "buffer-time", G_SETTINGS_BIND_DEFAULT);
+  g_settings_bind(settings, "latency-in", source, "latency-time", G_SETTINGS_BIND_DEFAULT);
+  g_settings_bind(settings, "buffer-in", sink, "buffer-time", G_SETTINGS_BIND_DEFAULT);
+  g_settings_bind(settings, "latency-in", sink, "latency-time", G_SETTINGS_BIND_DEFAULT);
 
-  g_settings_bind(settings, "blocksize-in", adapter, "blocksize",
-                  G_SETTINGS_BIND_DEFAULT);
+  g_settings_bind(settings, "blocksize-in", adapter, "blocksize", G_SETTINGS_BIND_DEFAULT);
 
   // element message callback
 
-  g_signal_connect(bus, "message::element", G_CALLBACK(on_message_element),
-                   this);
+  g_signal_connect(bus, "message::element", G_CALLBACK(on_message_element), this);
 
-  limiter = std::make_unique<Limiter>(
-      log_tag, "com.github.wwmm.pulseeffects.sourceoutputs.limiter");
-  compressor = std::make_unique<Compressor>(
-      log_tag, "com.github.wwmm.pulseeffects.sourceoutputs.compressor");
-  filter = std::make_unique<Filter>(
-      log_tag, "com.github.wwmm.pulseeffects.sourceoutputs.filter");
-  equalizer = std::make_unique<Equalizer>(
-      log_tag, "com.github.wwmm.pulseeffects.sourceoutputs.equalizer",
-      "com.github.wwmm.pulseeffects.sourceoutputs.equalizer.leftchannel",
-      "com.github.wwmm.pulseeffects.sourceoutputs.equalizer.rightchannel");
-  reverb = std::make_unique<Reverb>(
-      log_tag, "com.github.wwmm.pulseeffects.sourceoutputs.reverb");
-  gate = std::make_unique<Gate>(
-      log_tag, "com.github.wwmm.pulseeffects.sourceoutputs.gate");
-  deesser = std::make_unique<Deesser>(
-      log_tag, "com.github.wwmm.pulseeffects.sourceoutputs.deesser");
-  pitch = std::make_unique<Pitch>(
-      log_tag, "com.github.wwmm.pulseeffects.sourceoutputs.pitch");
-  webrtc = std::make_unique<Webrtc>(
-      log_tag, "com.github.wwmm.pulseeffects.sourceoutputs.webrtc",
-      pm->mic_sink_info->rate);
-  multiband_compressor = std::make_unique<MultibandCompressor>(
-      log_tag,
-      "com.github.wwmm.pulseeffects.sourceoutputs.multibandcompressor");
-  multiband_gate = std::make_unique<MultibandGate>(
-      log_tag, "com.github.wwmm.pulseeffects.sourceoutputs.multibandgate");
+  limiter = std::make_unique<Limiter>(log_tag, "com.github.wwmm.pulseeffects.sourceoutputs.limiter");
+  compressor = std::make_unique<Compressor>(log_tag, "com.github.wwmm.pulseeffects.sourceoutputs.compressor");
+  filter = std::make_unique<Filter>(log_tag, "com.github.wwmm.pulseeffects.sourceoutputs.filter");
+  equalizer = std::make_unique<Equalizer>(log_tag, "com.github.wwmm.pulseeffects.sourceoutputs.equalizer",
+                                          "com.github.wwmm.pulseeffects.sourceoutputs.equalizer.leftchannel",
+                                          "com.github.wwmm.pulseeffects.sourceoutputs.equalizer.rightchannel");
+  reverb = std::make_unique<Reverb>(log_tag, "com.github.wwmm.pulseeffects.sourceoutputs.reverb");
+  gate = std::make_unique<Gate>(log_tag, "com.github.wwmm.pulseeffects.sourceoutputs.gate");
+  deesser = std::make_unique<Deesser>(log_tag, "com.github.wwmm.pulseeffects.sourceoutputs.deesser");
+  pitch = std::make_unique<Pitch>(log_tag, "com.github.wwmm.pulseeffects.sourceoutputs.pitch");
+  webrtc =
+      std::make_unique<Webrtc>(log_tag, "com.github.wwmm.pulseeffects.sourceoutputs.webrtc", pm->mic_sink_info->rate);
+  multiband_compressor =
+      std::make_unique<MultibandCompressor>(log_tag, "com.github.wwmm.pulseeffects.sourceoutputs.multibandcompressor");
+  multiband_gate = std::make_unique<MultibandGate>(log_tag, "com.github.wwmm.pulseeffects.sourceoutputs.multibandgate");
 
   plugins.insert(std::make_pair(limiter->name, limiter->plugin));
   plugins.insert(std::make_pair(compressor->name, compressor->plugin));
@@ -133,27 +107,22 @@ SourceOutputEffects::SourceOutputEffects(PulseManager* pulse_manager)
   plugins.insert(std::make_pair(deesser->name, deesser->plugin));
   plugins.insert(std::make_pair(pitch->name, pitch->plugin));
   plugins.insert(std::make_pair(webrtc->name, webrtc->plugin));
-  plugins.insert(
-      std::make_pair(multiband_compressor->name, multiband_compressor->plugin));
+  plugins.insert(std::make_pair(multiband_compressor->name, multiband_compressor->plugin));
   plugins.insert(std::make_pair(multiband_gate->name, multiband_gate->plugin));
 
   add_plugins_to_pipeline();
 
-  g_signal_connect(child_settings, "changed::plugins",
-                   G_CALLBACK(on_plugins_order_changed<SourceOutputEffects>),
-                   this);
+  g_signal_connect(child_settings, "changed::plugins", G_CALLBACK(on_plugins_order_changed<SourceOutputEffects>), this);
 }
 
 SourceOutputEffects::~SourceOutputEffects() {
   util::debug(log_tag + "destroyed");
 }
 
-void SourceOutputEffects::on_app_added(
-    const std::shared_ptr<AppInfo>& app_info) {
+void SourceOutputEffects::on_app_added(const std::shared_ptr<AppInfo>& app_info) {
   PipelineBase::on_app_added(app_info);
 
-  auto enable_all =
-      g_settings_get_boolean(settings, "enable-all-sourceoutputs");
+  auto enable_all = g_settings_get_boolean(settings, "enable-all-sourceoutputs");
 
   if (enable_all && !app_info->connected) {
     pm->move_source_output_to_pulseeffects(app_info->name, app_info->index);
@@ -196,8 +165,7 @@ void SourceOutputEffects::add_plugins_to_pipeline() {
   for (auto v : plugins_order) {
     // checking if the plugin exists. If not we reset the list to default
 
-    if (std::find(default_order.begin(), default_order.end(), v) ==
-        default_order.end()) {
+    if (std::find(default_order.begin(), default_order.end(), v) == default_order.end()) {
       plugins_order = default_order;
 
       g_settings_reset(child_settings, "plugins");
@@ -222,6 +190,5 @@ void SourceOutputEffects::add_plugins_to_pipeline() {
     gst_element_link(plugins[plugins_order[n - 1]], plugins[plugins_order[n]]);
   }
 
-  gst_element_link(plugins[plugins_order[plugins_order.size() - 1]],
-                   identity_out);
+  gst_element_link(plugins[plugins_order[plugins_order.size() - 1]], identity_out);
 }
